@@ -76,10 +76,12 @@ App::Dochazka::CLI::Util - Various reusable components
 
 our @EXPORT_OK = qw( 
     authenticate_to_server 
+    datelist_from_token
     determine_employee
     lookup_employee 
     init_logger
     init_prompt
+    month_alpha_to_numeric
     normalize_date
     normalize_time
     parse_test
@@ -88,6 +90,21 @@ our @EXPORT_OK = qw(
     truncate_to
 );
 
+our %month_map = (
+    'jan' => 1,
+    'feb' => 2,
+    'mar' => 3,
+    'apr' => 4,
+    'may' => 5,
+    'jun' => 6,
+    'jul' => 7,
+    'aug' => 8,
+    'sep' => 9,
+    'oct' => 10,
+    'nov' => 11,
+    'dec' => 12,
+);
+
 
 
 =head1 FUNCTIONS
@@ -161,6 +178,66 @@ sub authenticate_to_server {
 }
 
 
+=head2 datelist_from_token
+
+Takes a numeric month and a _DATELIST token - e.g. "5,6,10-13,2".
+
+Convert the token into an array of dates and return a reference. So, upon
+success, the return value will look something like this:
+
+    [ "2015-01-01", "2015-01-06", "2015-01-22" ]
+
+If there's a problem, writes an error message to the log and returns
+undef.
+
+=cut
+
+sub datelist_from_token {
+    my ( $month, $token ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::datelist_from_token with month $month and token " . Dumper( $token ) );
+
+    if ( $month < 1 or $month > 12 ) {
+        $log->error( "bad numeric month passed to datelist_from_token()" );
+        return;
+    }
+
+    my @datelist;
+    #
+    # loop as long as subtokens are left
+    while ( defined( $token ) and my ( $subtoken ) = $token =~ m/^((\d{1,2})|(\d{1,2}-\d{1,2}))(?=(,|$))/ ) {
+
+        #
+        # 1. chew off the subtoken
+        if ( $token =~ m/^$subtoken,/ ) {
+            $token =~ s/^$subtoken,//;
+        } elsif ( $token =~ m/^$subtoken$/ ) {
+            $token =~ s/^$subtoken$//;
+        } else {
+            die "AGACDKDFLQERIIeee!";
+        }
+
+        #
+        # 2. if it's a range, convert it into a list of individual dates
+        if ( my ( $begin, $end ) = $subtoken =~ m/^(\d{1,2})-(\d{1,2})$/ ) {
+            if ( $begin >= $end ) {
+                die "AGHGGHSKSKDQ!!!!! Begin date must be less than end";
+            }
+            foreach my $n ( $begin..$end ) {
+                my $canonical_date = sprintf( "%04d-%02d-%02d", $prompt_year, $month, $n );
+                push @datelist, $canonical_date;
+            }
+        #
+        # 3. if not, convert it into a date
+        } else { # is a single date
+            my $canonical_date = sprintf( "%04d-%02d-%02d", $prompt_year, $month, $subtoken );
+            push @datelist, $canonical_date;
+        }
+   }
+
+   return \@datelist;
+}
+
+
 =head2 determine_employee
 
 Given what might possibly be an employee specification (as obtained from the
@@ -268,6 +345,24 @@ sub init_prompt {
 }
 
 
+=head2 month_alpha_to_numeric
+
+Given a month written in English (e.g. "January"), return the ordinal
+number of that month (i.e. 1 for January) or undef if it cannot be
+determined.
+
+=cut
+
+sub month_alpha_to_numeric {
+    my $alpha = shift;
+    return unless defined( $alpha );
+    my ( $month ) = $alpha =~ m/\A(\S\S\S)/;
+    $month = lc $month;
+    return unless exists( $month_map{ $month } );
+    return $month_map{ $month };
+}
+
+
 =head2 normalize_date
 
 Normalize a date entered by the user. A date can take the following forms
